@@ -1,11 +1,16 @@
+import sallron
 import time
 import sys
+import logging
 from subprocess import Popen
 from os.path import join, dirname, exists
+from os import environ
 
 _KILL_TIMEOUT = 3
 _PID_FILE = 'sallron.pid'
 
+enforcer_logger = logging.getLogger('enforcer')
+
 def send_message():
     """
     To be implemented.
@@ -15,12 +20,13 @@ def send_message():
         3. accompany message with deploy + customer name
     """
     if exists(_PID_FILE):
-        print("sallron had to be restarted, take a look at the error logs...")
+        enforcer_logger.warning("sallron had to be restarted, take a look at the error logs...")
     pass
 
 def write_pid(pid):
     with open(_PID_FILE, 'w') as w:
         w.write(pid)
+    enforcer_logger.info(f'pid {pid} written in {_PID_FILE}')
 
 def kill_pid(delete_file=True):
     '''Kill processes.'''
@@ -28,18 +34,21 @@ def kill_pid(delete_file=True):
         pid = rapid.read()
     if delete_file:
         Popen(f'rm {_PID_FILE}', shell=True)
-        print('.pid file purged')
+        enforcer_logger.info(f'{_PID_FILE} purged')
     Popen('kill %s' % pid, shell=True)
-    print('pid killed')
+    enforcer_logger.info(f'pid {pid} killed')
 
-def eternal_runner(filepath):
+def eternal_runner(filepath, test=False):
     while True:
         try:
             send_message()
+            enforcer_logger.info(f'Running {filepath} file')
             p = Popen(f"python3 {filepath}", shell=True)
+            if test:
+                raise KeyboardInterrupt
             p.wait()
         except (KeyboardInterrupt):
-            print('Exit signal received, shutting down.')
+            enforcer_logger.info('Exit signal received, shutting down.')
             time.sleep(_KILL_TIMEOUT)
             kill_pid()
             sys.exit()
